import 'dart:async';
import 'dart:ui';
import 'package:auto_size_text/auto_size_text.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:geolocator/geolocator.dart';
import 'package:we_clean_project/loadingScreen.dart';
import 'package:we_clean_project/meetingSettings.dart';
import 'package:we_clean_project/newsPage.dart';
import 'constants.dart' as constants;
import 'package:tcp_socket_connection/tcp_socket_connection.dart';
import 'dart:convert';
import 'package:geocoding/geocoding.dart';
import 'package:animated_icon_button/animated_icon_button.dart';
import 'package:we_clean_project/meetingMarker.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';
//import 'package:geocoder/geocoder.dart';
import 'package:we_clean_project/markerInfo.dart';
import 'package:maps_launcher/maps_launcher.dart';
import 'package:modal_bottom_sheet/modal_bottom_sheet.dart';
import 'package:hive/hive.dart';
import 'package:path_provider/path_provider.dart' as path_provider;
import 'package:we_clean_project/hiveDBHelper.dart';

void main() {
  runApp(MyApp());

}

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: constants.APP_THEME_COLOR,
        visualDensity: VisualDensity.adaptivePlatformDensity,
        fontFamily: 'Nunito',
      ),
      home: MyHomePage(title: 'WE F***ING CLEAN'),
      /*localizationsDelegates: [
        GlobalMaterialLocalizations.delegate,
        GlobalWidgetsLocalizations.delegate,
        GlobalCupertinoLocalizations.delegate,
      ],*/
      /*supportedLocales: [
        const Locale('it'),
        const Locale('en'),
      ],*/
    );
  }
}


class MyHomePage extends StatefulWidget {
  MyHomePage({Key key, this.title}) : super(key: key);
  final String title;
  @override
  _MyHomePageState createState() => _MyHomePageState();
}


class _MyHomePageState extends State<MyHomePage> with TickerProviderStateMixin{
  Position position;
  TcpSocketConnection server=new TcpSocketConnection("192.168.1.110", constants.SERVER_PORT);
  double mapZoom=10;
  LatLng mapPosition=new LatLng(10,10);
  final GlobalKey<ScaffoldState> _scaffoldKey = new GlobalKey<ScaffoldState>();
  bool isPinningLocation=false;
  List<MeetingMarker> meetingMarkers=new List<MeetingMarker>();
  LatLng pickedLocation;
  bool positionLoaded=false;
  bool searchingForPlace=false;
  bool isShowingInfo=false;
  Completer<GoogleMapController> _controllerMap = Completer();
  Set<Marker> markersToShow=new Set<Marker>();
  var textDialogSearchController = TextEditingController();
  MarkerInfo markerinfo=new MarkerInfo();
  AnimationController controllerTranslateLateral;
  Animation translateLateral;
  AnimationController controllerWidthSize;
  Animation widthSize;

  static final CameraPosition _initialPosition = CameraPosition(
    target: LatLng(41.902782,	12.496366),
    zoom: 10,
  );

  /*static final CameraPosition _kGooglePlex = CameraPosition(
    target: LatLng(37.42796133580664, -122.085749655962),
    zoom: 15,
  );

  static final CameraPosition _kLake = CameraPosition(
      bearing: 192.8334901395799,
      target: LatLng(37.43296265331129, -122.08832357078792),
      tilt: 59.440717697143555,
      zoom: 19.151926040649414);
*/



  @override
  void initState() {
    setMarkerPosition();
    controllerTranslateLateral=AnimationController(vsync: this, duration: Duration(milliseconds: 400),reverseDuration: Duration(milliseconds: 400),);

    controllerTranslateLateral.addListener(() {
      setState(() {
        //translateLateral.value;
      });
    });



    translateLateral=Tween<double>(begin: 25, end: 35).animate(CurvedAnimation(parent: controllerTranslateLateral, curve: Interval(
      0,
      1,
      curve: Curves.ease,
    )));
    controllerWidthSize=AnimationController(vsync: this, duration: Duration(milliseconds: 400),reverseDuration: Duration(milliseconds: 400),);

    controllerWidthSize.addListener(() {
      setState(() {
        //widthSize.value;
      });
    });

    widthSize=Tween<double>(begin: 10, end: 140).animate(CurvedAnimation(parent: controllerWidthSize, curve: Interval(
      0,
      1,
      curve: Curves.ease,
    )));
    hiveInit();

    super.initState();

  }

  void hiveInit() async{
    final appDocumentDirectory= await path_provider.getApplicationDocumentsDirectory();
    Hive.init(appDocumentDirectory.path);
    HiveDBHelper.initMyHiveDB();
  }

  double getHeight(){
    var padding = MediaQuery.of(context).padding;
    double height = MediaQuery.of(context).size.height;
    double newheight = height - padding.top - padding.bottom-325;
    double toReturn=newheight/(height - padding.top - padding.bottom);
    return toReturn;
  }

  void setMarkerPosition() async{
    await _determinePosition();
    if(position==null){
      print("Position is null");
      return;
    }
    setState(() {
      markersToShow.add(new Marker(
        markerId: new MarkerId("PositionMarker"),
        position: new LatLng(position.latitude,position.longitude),

      ));
    });

    _goToPosition(new LatLng(position.latitude,position.longitude),15);
    print("Set Position Marker");
    askMeetingMarkers(new LatLng(position.latitude, position.longitude));
  }

  Future<void> _goToPosition(LatLng pos, double zoom) async {
    final GoogleMapController controller = await _controllerMap.future;
    controller.animateCamera(CameraUpdate.newCameraPosition(new CameraPosition(
      target: pos,
      zoom: zoom,
    )));
  }

  /////////TO FIND POINTS AT GIVEN DISTANCE YOU HAVE TO SEND LATITUDE AND LONGITUDE AND GIVEN DISTANCE. THEN THE SERVER WILL FIND THE DIFFERENCE BETWEEN LATITUDE AND LONGITUDE OF POINTS AND MY POSITION.
  /////////THEN I HAVE TO CHECK THAT            -SQUARED_ROOT((GIVEN_DISTANCE/111)-LATITUDE_DISTANCE^2))<=LONGITUDE_DISTANCE<=SQUARED_ROOT((GIVEN_DISTANCE/111)-LATITUDE_DISTANCE^2)) AND IF IT WORKS I HAVE
  /////////TO SEND BACK THAT POINT WITH ITS INFORMATION.

  void askMeetingMarkers(LatLng latlng) async{
    await server.connect(5000, "EOS", messageReceived);
    server.sendMessage("GETMEETINGBYPOSITION%_%"+latlng.latitude.toString()+"%_%"+latlng.longitude.toString()+"%_%EOS");
  }

  void messageReceived(String message){
    if(message.startsWith("NONE")){
      print("THERE ARE NO POINTS NEAR YOU");
    }
    if(message.startsWith("MEETINGS")){
      print("RECEIVED: "+message);
      message=message.replaceAll("MEETINGS%_%", "");
      List<MeetingMarker> markers;
      markers=(json.decode(message) as List).map((i) => MeetingMarker.fromJson(i)).toList();
      print("HELLOOOOOOO"+markers.length.toString());
      for(int i=0;i<markers.length;i++){
        bool found=false;
        for(int k=0;k<meetingMarkers.length;k++){
          if(markers[i].id.compareTo(meetingMarkers[k].id)==0){
            found=true;
            print("MARKER ALREADY IN: "+markers[i].toString());
          }
        }
        if(!found){
          print("MARKER NOT IN: "+markers[i].toString());
          if(markers[i].deadLine.compareTo("2000-01-01 00:00:00")==0){
            markers[i].deadLine=null;
          }
          markers[i].marker=new Marker(
            markerId: new MarkerId(markers[i].id),
            onTap: ()=>showMarkerInfo(markers[i]),
            position: new LatLng(markers[i].latitude,markers[i].longitude),
          );
          setState(() {
            markersToShow.add(markers[i].marker);
          });
          meetingMarkers.add(markers[i]);
        }
      }
    }
    server.disconnect();
  }

  void showMarkerInfo(MeetingMarker m){
    showMaterialModalBottomSheet(
      backgroundColor: Colors.transparent,
      context: context,
      builder: (context) => SingleChildScrollView(
        controller: ModalScrollController.of(context),
        child: new MarkerInfo(
          marker: m,
        ),
      ),
    );
    /*
    showModalBottomSheet(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.vertical(top: Radius.circular(25.0)),
      ),
        backgroundColor: Colors.transparent,
      context: context,
      isScrollControlled: false, // set this to true
      clipBehavior: Clip.antiAliasWithSaveLayer,
      barrierColor: Colors.black.withAlpha(50),
      isDismissible: true,
      //backgroundColor: Colors.transparent,
      builder: (_) {
        return DraggableScrollableSheet(
          //maxChildSize: getHeight(),
          maxChildSize: 1,
          builder: (_, controller) {
            return new MarkerInfo(
              marker: m,
              controller: controller,
            );
          },
        );
      },
    );*/
/*
    showModalBottomSheet(
      context: context,
      isScrollControlled: true, // set this to true
      //barrierColor: Colors.black.withAlpha(1),
      //backgroundColor: Colors.transparent,
      builder: (_) {
        return DraggableScrollableSheet(
          expand: true,
          builder: (_, controller) {
            return new MarkerInfo(
              marker: m,
              controller: controller,
            );
          },
        );
      },

      //backgroundColor: Colors.transparent,
    );*/

    setState(() {
      markerinfo=new MarkerInfo(
        marker: m,
      );
      //info=m;
     // isShowingInfo=true;
    });

    /*
    showDialog(
        context: context,
        builder: (context) {
          return StatefulBuilder(
              builder: (context, setState) {
                return Dialog(
                  backgroundColor: Colors.transparent,
                  child: new BackdropFilter(
                    filter: ImageFilter.blur(sigmaX: 5, sigmaY: 5),
                    child:SingleChildScrollView(

                      child: Container(
                          height: 470.0,
                          width: 400.0,
                          decoration: BoxDecoration(
                              color: constants.LIGHT_GREEN,
                              //color: Colors.cyan[300],
                              borderRadius: BorderRadius.circular(30)
                          ),
                          child: Padding(
                            padding: EdgeInsets.all(5),
                            child: Column(
                                children: <Widget>[
                                  Text(m.title),
                                  Text(m.startDateTime),
                                  Text(m.description),
                                  Text(m.maxPartecipants.toString()),
                                  //Text(m.)
                                ]
                            ),
                          )
                      ),
                    ),
                  ),
                );
              }
          );}
    ).then((val){
      print("CLOSED");
    });*/
  }

  void addMarker(MeetingMarker mark){
    server.connect(5000, "EOS", messageReceived);
    server.sendMessage("ADD_MARKER%_%"+mark.toJson().toString()+"%_%EOF");
  }


  _determinePosition() async {
    bool serviceEnabled;
    LocationPermission permission;

    serviceEnabled = await Geolocator.isLocationServiceEnabled();
    if (!serviceEnabled) {
      return Future.error('Location services are disabled.');
    }

    permission = await Geolocator.checkPermission();
    if (permission == LocationPermission.deniedForever) {
      return Future.error(
          'Location permissions are permantly denied, we cannot request permissions.');
    }

    if (permission == LocationPermission.denied) {
      permission = await Geolocator.requestPermission();
      if (permission != LocationPermission.whileInUse &&
          permission != LocationPermission.always) {
        return Future.error(
            'Location permissions are denied (actual value: $permission).');
      }
    }
    position= await Geolocator.getCurrentPosition();
    startTimeout(1500);
  }

  void searchLocation()async {
    /*final query = "Via Zuannen Caschini 38, Santorso";
    var addresses = await Geocoder.local.findAddressesFromQuery(query);
    var first = addresses.first;
    print("${first.featureName} : ${first.coordinates}");*/

    String location=textDialogSearchController.text;
    List<Location> locations = await locationFromAddress(location);
    /*for(int i=0;i<locations.length;i++){
      print("LOCATION=" +locations[i].toString());
    }*/
    if(locations.length>0){
      _goToPosition(new LatLng(locations[0].latitude, locations[0].longitude), 14);
      askMeetingMarkers(new LatLng(locations[0].latitude, locations[0].longitude));
    }else{
      print("NO LOCATION FOUND");
    }

    /*
    setState(() {
      searchingForPlace=true;
    });*/

  }

  startTimeout([int milliseconds]) {
    var duration = milliseconds == null ? constants.timeout : constants.ms * milliseconds;
    return new Timer(duration, handleTimeout);
  }

  void handleTimeout() {  // callback function
    setState(() {
      positionLoaded=true;
    });

  }


  void tapMap(LatLng latlng){
    if(isShowingInfo){
      setState(() {
        isShowingInfo=false;
      });

    }
    if(isPinningLocation) {
      if(controllerWidthSize.status!=AnimationStatus.completed){
        controllerTranslateLateral.forward();
        controllerWidthSize.forward();
      }

      removeAddedMarker();
      print(latlng);
      pickedLocation=latlng;
      setState(() {
        markersToShow.add(new Marker(
          markerId: new MarkerId("ChoosePositionMarker"),
          position: latlng,
        ));
      });
    }


  }

  void showMenu(){
    Navigator.push(
        context,
        MaterialPageRoute(builder: (context) => MeetingSettings(
          position: pickedLocation,
        )));
  }

  void removeAddedMarker(){
    for(int i=0;i<markersToShow.length;i++){
        if(markersToShow.elementAt(i).markerId.value.compareTo("ChoosePositionMarker")==0){
          setState(() {
            markersToShow.remove(markersToShow.elementAt(i));
          });
          break;
        }
    }
  }

  @override
  Widget build(BuildContext context) {
    GoogleMap googleMap=new GoogleMap(
      onTap: tapMap,
      mapType: MapType.normal,
      mapToolbarEnabled: false,
      markers: markersToShow,
      zoomControlsEnabled: false,
      initialCameraPosition: _initialPosition,
      onMapCreated: (GoogleMapController controller) {
        _controllerMap.complete(controller);
      },
    );

    //MarkerInfo markerinfo=new MarkerInfo();

    ListView menu=new ListView(
      children: [
        Container(
          height: 200,
          decoration: BoxDecoration(
            color: constants.LIGHT_GREEN,
          ),
        ),
        ButtonTheme(
          minWidth: double.infinity,
          child: MaterialButton(
            onPressed: () {Navigator.push(
                context,
                MaterialPageRoute(builder: (context) => NewsPage(
                )));
            },
            child:Card(
              child: ListTile(
                leading: FlutterLogo(),
                title: Text('Hello'),
              ),
            ),
          ),
        ),
        ButtonTheme(
          minWidth: double.infinity,
          child: MaterialButton(
            onPressed: () {print("BUTTON PRESSED");},
            child:Card(
              child: ListTile(
                leading: FlutterLogo(),
                title: Text('Hello'),
              ),
            ),
          ),
        ),
        ButtonTheme(
          minWidth: double.infinity,
          child: MaterialButton(
            onPressed: () {print("BUTTON PRESSED");},
            child:Card(
              child: ListTile(
                leading: FlutterLogo(),
                title: Text('Hello'),
              ),
            ),
          ),
        ),
      ],
    );

    return  Scaffold(
        key:_scaffoldKey,

        //    **SIDE MENU**
        drawer: new Drawer(
          child: menu,
        ),
        body: AnnotatedRegion<SystemUiOverlayStyle>(
          value: SystemUiOverlayStyle(
            statusBarColor: constants.LIGHT_GREEN,
          ),

          child: Align(
            alignment: Alignment.topCenter,
            child: SafeArea(
              left: true,
              top: true,
              right: true,
              bottom: true,
              //minimum: const EdgeInsets.only(left:16.0, right: 16.0, bottom: 16.0),
              child:Stack(
                overflow: Overflow.visible,
                children: <Widget>[
                  Positioned(child: googleMap,),
                  /*Positioned(
                    child: Container(
                      height: 20,
                      color: constants.LIGHT_GREEN,
                    ),
                  ),*/
                  Positioned(
                    child: Container(
                      height: 60,
                      decoration: BoxDecoration(
                        color: constants.LIGHT_GREEN,
                        //color: Colors.blueGrey,
                        borderRadius: BorderRadius.vertical(bottom: Radius.circular(20)),
                        boxShadow: [
                          BoxShadow(
                            color: Colors.black.withOpacity(0.3),
                            spreadRadius: 5,
                            blurRadius: 7,
                            offset: Offset(0, 3), // changes position of shadow
                          ),
                        ],

                      ),
                      child:Row(
                        children: [
                          IconButton(
                            icon: Icon(Icons.menu,color: Colors.white, size: 30,),
                            onPressed: () {
                              _scaffoldKey.currentState.openDrawer();
                            },
                          ),
                          Expanded(
                            child:  Container(
                              height: 40,
                              child: Padding(
                                padding: EdgeInsets.only(left: 10,right:10),
                                child:Center(
                                        child:TextField(
                                          controller: textDialogSearchController,
                                          decoration: InputDecoration(
                                            contentPadding: EdgeInsets.only(
                                              bottom: 10,  // HERE THE IMPORTANT PART
                                            ),
                                            border: InputBorder.none,
                                            hintText: "Cerca...",
                                            hintStyle: TextStyle(fontSize: 20.0),
                                          ),
                                          style: TextStyle(fontSize: 20,),
                                          maxLines: 1,
                                        )
                                ),
                              ),
                              decoration: BoxDecoration(
                                color: constants.DARK_GREEN,
                                //color: Colors.blueGrey,
                                borderRadius: BorderRadius.circular(20),

                              ),
                            ),
                          ),

                          IconButton(
                            icon: Icon(Icons.search,color: Colors.white,size: 30,),
                            onPressed: () => searchLocation(),
                          ),
                        ],
                      ),


                    ),
                  ),
                  /*Positioned(
                    top: 70,
                      child: Container(
                      color: constants.LIGHT_GREEN,
                        child: Text(
                          "PREMI SULLA MAPPA PER SCEGLIERE UN PUNTO DI INCONTRO",
                          style: TextStyle(color: Colors.white,fontSize: 20),
                        ),
                    ),
                  ),*/
                  /*Positioned.fill(
                      child: Visibility(
                        visible: searchingForPlace,
                        child: Container(
                          color: constants.WHITE,
                          child:menu,
                        )
                      )

                  ),*/

                  /*
                  Positioned(
                      bottom: 0,
                      left: 0,
                      right: 0,

                      child: Visibility(
                        visible: isShowingInfo,
                        child: markerinfo,
                      )
                  ),*/

                  /*SizedBox.expand(
                      child: Visibility(
                        visible: isShowingInfo,
                        child: DraggableScrollableSheet(
                            builder: (BuildContext context, ScrollController scrollController) {
                              return new MarkerInfo(
                                marker: info,
                                controller: scrollController,
                              );
                            }
                        ),
                      )
                  ),*/
                  Positioned.fill(
                      child: Visibility(
                        visible: !positionLoaded,
                        child: LoadingScreen(),
                      )

                  ),
                ],

              ),
            ),
          ),
        ),
      //

        floatingActionButton:
        Visibility(
          visible: positionLoaded,
          child:Stack(
            children: [


              Positioned(
                bottom:10,
                right:translateLateral.value,
                //child:
                //Visibility(
                child:Container(
                    width: widthSize.value,
                    height: 40.0,
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(15),
                      color:constants.LIGHT_GREEN,
                      boxShadow: [
                        BoxShadow(
                          color: Colors.black.withOpacity(0.3),
                          spreadRadius: 5,
                          blurRadius: 7,
                          offset: Offset(0, 3), // changes position of shadow
                        ),
                      ],
                    ),
                    child: new RawMaterialButton(
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.all(Radius.circular(15.0)),
                      ),
                      elevation: 0.0,
                      child:AutoSizeText("Conferma",style: TextStyle(color: Colors.white,fontSize: 18), maxFontSize: 18, maxLines: 1,),
                      onPressed: () =>showMenu(),
                    )
                ),

                //visible: (pickedLocation!=null),
                //),
              ),

              Align(
                alignment: Alignment.bottomRight,
                    child: Container(
                      decoration: BoxDecoration(
                        shape: BoxShape.circle,
                        boxShadow: [
                          BoxShadow(
                            color: Colors.black.withOpacity(0.3),
                            spreadRadius: 5,
                            blurRadius: 7,
                            offset: Offset(0, 3), // changes position of shadow
                          ),
                        ],
                      ),

                      child:AnimatedIconButton(


                        endBackgroundColor: constants.LIGHT_GREEN,
                        startBackgroundColor: constants.LIGHT_GREEN,
                        size: 30,
                        onPressed: () {
                          //showMenu();
                          if(isPinningLocation){
                            pickedLocation=null;
                            print(markersToShow.length);
                            removeAddedMarker();
                            print("REMOVING");
                            print(markersToShow.length);
                            controllerTranslateLateral.reverse();
                            controllerWidthSize.reverse();

                          }else{
                            print("LOLasdasd");

                          }
                          isPinningLocation=(!isPinningLocation);
                          print(isPinningLocation.toString());
                        },
                        duration: Duration(milliseconds: 300),
                        endIcon: Icon(
                          Icons.close,
                          color: constants.WHITE,
                        ),
                        startIcon: Icon(
                          Icons.add,
                          color: constants.WHITE,
                        ),
                      ),
                    )
              ),
            ],
          )
        ),
    );
  }
}



/*
class _MyHomePageState extends State<MyHomePage> {
  Position position;
  FlutterMap flutterMap;
  MarkerLayerOptions markerLayerOptions;
  TcpSocketConnection server=new TcpSocketConnection("192.168.1.110", constants.SERVER_PORT);
  double mapZoom=10;
  LatLng mapPosition=new LatLng(10,10);
  final MapController mapController = new MapController();
  final GlobalKey<ScaffoldState> _scaffoldKey = new GlobalKey<ScaffoldState>();
  bool isPinningLocation=false;
  List<MeetingMarkero> meetingMarkers=new List<MeetingMarkero>();
  LatLng pickedLocation;
  bool positionLoaded=false;


  @override
  void initState() {
    markerLayerOptions=new MarkerLayerOptions(
        markers: [
        ]);
    setMarkerPosition();
    super.initState();
  }

  void setMarkerPosition() async{
    await _determinePosition();
    if(position==null){
      print("Position is null");
      return;
    }
    setState(() {
      markerLayerOptions.markers.insert(0,
          new Marker(         //POSITION MARKER
            width: 25.0,
            height: 25.0,
            point: new LatLng(position.latitude, position.longitude),
            builder: (ctx) =>
            new Container(
                decoration: BoxDecoration(
                  color: constants.POSITION_COLOR_UNHIGHLIGHTED,
                  borderRadius: BorderRadius.circular(12.5),
                ),
                child: Center(
                    child: Container(
                      width: 12.0,
                      height: 12.0,
                      decoration: BoxDecoration(
                        color: constants.LIGHT_GREEN,
                        borderRadius: BorderRadius.circular(6),
                      ),
                    )
                )
            ),
          ));
    });
    mapController.move(new LatLng(position.latitude,position.longitude),constants.MAP_ZOOM);
    print("Set Position Marker");
    askMeetingMarkers();
  }

  /////////TO FIND POINTS AT GIVEN DISTANCE YOU HAVE TO SEND LATITUDE AND LONGITUDE AND GIVEN DISTANCE. THEN THE SERVER WILL FIND THE DIFFERENCE BETWEEN LATITUDE AND LONGITUDE OF POINTS AND MY POSITION.
  /////////THEN I HAVE TO CHECK THAT            -SQUARED_ROOT((GIVEN_DISTANCE/111)-LATITUDE_DISTANCE^2))<=LONGITUDE_DISTANCE<=SQUARED_ROOT((GIVEN_DISTANCE/111)-LATITUDE_DISTANCE^2)) AND IF IT WORKS I HAVE
  /////////TO SEND BACK THAT POINT WITH ITS INFORMATION.

  void askMeetingMarkers() async{
    await server.connect(5000, "EOS", messageReceived);
    server.sendMessage("GETMEETINGBYPOSITION%_%"+position.latitude.toString()+"%_%"+position.longitude.toString()+"%_%EOS");
  }

  void messageReceived(String message){
    if(message.startsWith("NONE")){
      print("THERE ARE NO POINTS NEAR YOU");
    }
    if(message.startsWith("MEETINGS")){
      print("RECEIVED");
      message=message.replaceAll("MEETINGS%_%", "");
      List<MeetingMarkero> markers;
      markers=(json.decode(message) as List).map((i) => MeetingMarkero.fromJson(i)).toList();

      for(int i=0;i<markers.length;i++){
        if(markers[i].deadLine.compareTo("2000-01-01 00:00:00")==0){
          markers[i].deadLine=null;
        }
        markers[i].marker=new Marker(
          point: new LatLng(markers[i].latitude,markers[i].longitude),
          width: 20,
          height: 20,
          builder: (ctx) =>
          new Container(
              decoration: BoxDecoration(
                color: constants.LIGHT_GREEN,
                borderRadius: BorderRadius.circular(12.5),
              ),
            child: GestureDetector(onTap: ()=>showMarkerInfo(markers[i]),child: Icon(Icons.info_outline, color: Colors.white,),
            ),
          ),
        );
        setState(() {
          markerLayerOptions.markers.add(markers[i].marker);
        });
        meetingMarkers.addAll(markers);
      }
    }
    server.disconnect();
  }

  void showMarkerInfo(MeetingMarkero m){
    showDialog(
        context: context,
        builder: (context) {
          return StatefulBuilder(
              builder: (context, setState) {
                return Dialog(
                  backgroundColor: Colors.transparent,
                  child: new BackdropFilter(
                    filter: ImageFilter.blur(sigmaX: 5, sigmaY: 5),
                    child:SingleChildScrollView(

                      child: Container(
                          height: 470.0,
                          width: 400.0,
                          decoration: BoxDecoration(
                              color: constants.LIGHT_GREEN,
                              //color: Colors.cyan[300],
                              borderRadius: BorderRadius.circular(30)
                          ),
                          child: Padding(
                            padding: EdgeInsets.all(5),
                            child: Column(
                                children: <Widget>[
                                  Text(m.title),
                                  Text(m.startDateTime),
                                  Text(m.description),
                                  Text(m.maxPartecipants.toString()),
                                  //Text(m.)
                                ]
                            ),
                          )
                      ),
                    ),
                  ),
                );
              }
          );}
    ).then((val){
      print("CLOSED");
    });
  }

  void addMarker(MeetingMarkero mark){
    server.connect(5000, "EOS", messageReceived);
    server.sendMessage("ADD_MARKER%_%"+mark.toJson().toString()+"%_%EOF");
  }


  _determinePosition() async {
    bool serviceEnabled;
    LocationPermission permission;

    serviceEnabled = await Geolocator.isLocationServiceEnabled();
    if (!serviceEnabled) {
      return Future.error('Location services are disabled.');
    }

    permission = await Geolocator.checkPermission();
    if (permission == LocationPermission.deniedForever) {
      return Future.error(
          'Location permissions are permantly denied, we cannot request permissions.');
    }

    if (permission == LocationPermission.denied) {
      permission = await Geolocator.requestPermission();
      if (permission != LocationPermission.whileInUse &&
          permission != LocationPermission.always) {
        return Future.error(
            'Location permissions are denied (actual value: $permission).');
      }
    }
    position= await Geolocator.getCurrentPosition();
    startTimeout(1500);

  }

  startTimeout([int milliseconds]) {
    var duration = milliseconds == null ? constants.timeout : constants.ms * milliseconds;
    return new Timer(duration, handleTimeout);
  }

  void handleTimeout() {  // callback function
    setState(() {
      positionLoaded=true;
    });
  }


  void tapMap(LatLng latlng){
    if(isPinningLocation) {
      removeAddedMarker();
      print(latlng);
      pickedLocation=latlng;
      setState(() {
        markerLayerOptions.markers.add( new Marker(         //POSITION MARKER
            width: 25.0,
            height: 25.0,
            point: latlng,
            builder: (ctx) =>
            new Container(
              decoration: BoxDecoration(
                color: Colors.red,
                borderRadius: BorderRadius.circular(12.5),
              ),
            )
        ));
      });
    }
  }

  void showMenu(){
    Navigator.push(
        context,
        MaterialPageRoute(builder: (context) => TestGoogleMap(
        )));
    /*
    Navigator.push(
        context,
        MaterialPageRoute(builder: (context) => MeetingSettings(
          position: pickedLocation,
        )));*/
  }

  void removeAddedMarker(){
    for(int i=1;i<markerLayerOptions.markers.length;i++){
      bool found=false;
      for(int k=0;k<meetingMarkers.length;k++){
        if(markerLayerOptions.markers.elementAt(i).hashCode==meetingMarkers[k].marker.hashCode){
          found=true;
        }
      }
      if(!found){
        setState(() {
          markerLayerOptions.markers.removeAt(i);
        });
        break;
      }
    }
  }

  @override
  Widget build(BuildContext context) {




    flutterMap=new FlutterMap(
      mapController: mapController,
      options: new MapOptions(
        center: new LatLng(0,0),
        zoom: 2,
        maxZoom: constants.MAP_MAX_ZOOM,
        onTap: tapMap,

      ),
      layers: [
        new TileLayerOptions(

          //retinaMode: true,
            urlTemplate: "https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png",
            subdomains: ['a', 'b', 'c']
        ),
        markerLayerOptions,
      ],
    );

    ListView menu=new ListView(
      children: [
        Container(
          height: 200,
          decoration: BoxDecoration(
            color: constants.LIGHT_GREEN,
          ),
        ),
        ButtonTheme(
          minWidth: double.infinity,
          child: MaterialButton(
            onPressed: () {print("BUTTON PRESSED");},
            child:Card(
              child: ListTile(
                leading: FlutterLogo(),
                title: Text('Hello'),
              ),
            ),
          ),
        ),
        ButtonTheme(
          minWidth: double.infinity,
          child: MaterialButton(
            onPressed: () {print("BUTTON PRESSED");},
            child:Card(
              child: ListTile(
                leading: FlutterLogo(),
                title: Text('Hello'),
              ),
            ),
          ),
        ),
        ButtonTheme(
          minWidth: double.infinity,
          child: MaterialButton(
            onPressed: () {print("BUTTON PRESSED");},
            child:Card(
              child: ListTile(
                leading: FlutterLogo(),
                title: Text('Hello'),
              ),
            ),
          ),
        ),
      ],
    );

    return  Scaffold(
      key:_scaffoldKey,
        //    **SIDE MENU**
        drawer: new Drawer(
          child: menu,
        ),
        body: AnnotatedRegion<SystemUiOverlayStyle>(
          value: SystemUiOverlayStyle(
            statusBarColor: constants.LIGHT_GREEN,
          ),

          child: Align(
            alignment: Alignment.topCenter,
            child: SafeArea(
              left: true,
              top: true,
              right: true,
              bottom: true,
              //minimum: const EdgeInsets.only(left:16.0, right: 16.0, bottom: 16.0),
              child:Stack(
                overflow: Overflow.visible,
                children: <Widget>[
                  Positioned(child: flutterMap,),
                  Positioned(
                    child: Container(
                      height: 20,
                      color: constants.LIGHT_GREEN,
                    ),
                  ),
                  Positioned(
                    child: Container(
                        height: 60,
                        decoration: BoxDecoration(
                          color: constants.LIGHT_GREEN,
                          //color: Colors.blueGrey,
                          borderRadius: BorderRadius.circular(20),

                        ),
                        child:Row(
                          children: [
                            IconButton(
                              icon: Icon(Icons.menu,color: Colors.white, size: 30,),
                              onPressed: () {
                                _scaffoldKey.currentState.openDrawer();
                              },
                            ),
                            Expanded(
                              child:  Container(
                                height: 40,
                                child: Padding(
                                  padding: EdgeInsets.only(left: 10,right:10),
                                  child:Align(

                                    alignment: Alignment.centerLeft,
                                    child:Text(
                                      "Cerca...",
                                      style: TextStyle(
                                        color: Colors.white,
                                        fontSize: 20,
                                      ),
                                    ),
                                  ),
                                ),
                                decoration: BoxDecoration(
                                  color: constants.DARK_GREEN,
                                  //color: Colors.blueGrey,
                                  borderRadius: BorderRadius.circular(20),

                                ),
                              ),
                            ),

                            IconButton(
                              icon: Icon(Icons.search,color: Colors.white,size: 30,),
                              onPressed: () {
                                //_scaffoldKey.currentState.openDrawer();
                              },
                            ),
                          ],
                        ),


                    ),
                  ),
                  /*Positioned(
                    top: 70,
                      child: Container(
                      color: constants.LIGHT_GREEN,
                        child: Text(
                          "PREMI SULLA MAPPA PER SCEGLIERE UN PUNTO DI INCONTRO",
                          style: TextStyle(color: Colors.white,fontSize: 20),
                        ),
                    ),
                  ),*/
                  Positioned.fill(
                    child: Visibility(
                      visible: !positionLoaded,
                      child: LoadingScreen(),
                    )

                  ),
                ],

              ),
            ),
          ),
        ),

        floatingActionButton:  Stack(
          children: [
            Positioned(
              bottom:10,
              right:35,
              child:
              Visibility(
                child:Container(
                    width: 140.0,
                    height: 40.0,
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(15),
                      color:constants.LIGHT_GREEN,
                    ),
                    child: new RawMaterialButton(
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.all(Radius.circular(15.0)),
                      ),
                      elevation: 0.0,
                      child:Text("Conferma",style: TextStyle(color: Colors.white,fontSize: 18),),
                      onPressed: () =>showMenu(),
                    )
                ),
                visible: (pickedLocation!=null),
              ),
            ),

            Align(
                alignment: Alignment.bottomRight,
                child: Visibility(
                    visible: positionLoaded,
                  child:AnimatedIconButton(
                    endBackgroundColor: constants.LIGHT_GREEN,
                    startBackgroundColor: constants.LIGHT_GREEN,
                    size: 30,
                    onPressed: () {
                      if(isPinningLocation){
                        pickedLocation=null;
                        removeAddedMarker();
                      }else{

                      }
                      isPinningLocation=(!isPinningLocation);
                    },
                    duration: Duration(milliseconds: 300),
                    endIcon: Icon(
                      Icons.close,
                      color: constants.WHITE,
                    ),
                    startIcon: Icon(
                      Icons.add,
                      color: constants.WHITE,
                    ),
                  ),
                ),
            ),
          ],
        )
      /*

        Row(
            children: [
              Visibility(
                child:GestureDetector(
                  onTap: () =>showMenu(),
                  child: Container(
                      height: 40,
                      width: 140,
                      decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(15),
                        color:constants.LIGHT_GREEN,
                      ),
                      child: Center(
                          child:Text("Conferma",style: TextStyle(color: Colors.white,fontSize: 18),)
                      )
                  ),
                ),
                visible: (pickedLocation!=null),
              ),
              FloatingActionButton(
                onPressed: () {},
                child:AnimateIcons(
                  startIcon: Icons.add,
                  endIcon: Icons.close,
                  size:30,
                  controller: controllerAnimatedFloatingActionButton,
                  // add this tooltip for the start icon
                  startTooltip: 'Icons.add',
                  // add this tooltip for the end icon
                  endTooltip: 'Icons.close',
                  onStartIconPress: () {
                    isPinningLocation=true;
                    print("Clicked on Add Icon");
                    return true;
                  },
                  onEndIconPress: () {
                    isPinningLocation=false;
                    pickedLocation=null;
                    removeAddedMarker();
                    return true;
                  },
                  duration: Duration(milliseconds: 500),
                  color: Colors.white,
                  clockwise: false,
                ),
                //child: Icon(Icons.add),
                backgroundColor: constants.LIGHT_GREEN,
              )
            ],
          )*/


/*
          child: Stack(

            children: [
              Positioned(
                top:10,
                right:35,
                child:
                Visibility(
                  child:GestureDetector(
                    onTap: () =>showMenu(),
                    child: Container(
                        height: 40,
                        width: 140,
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(15),
                          color:constants.LIGHT_GREEN,
                        ),
                        child: Center(
                            child:Text("Conferma",style: TextStyle(color: Colors.white,fontSize: 18),)
                        )
                    ),
                  ),
                  visible: (pickedLocation!=null),
                ),
              ),
              Align(
                  alignment: Alignment.bottomRight,
                  child:
                  FloatingActionButton(
                    onPressed: () {},
                    child:AnimateIcons(
                      startIcon: Icons.add,
                      endIcon: Icons.close,
                      size:30,
                      controller: controllerAnimatedFloatingActionButton,
                      // add this tooltip for the start icon
                      startTooltip: 'Icons.add',
                      // add this tooltip for the end icon
                      endTooltip: 'Icons.close',
                      onStartIconPress: () {
                        isPinningLocation=true;
                        print("Clicked on Add Icon");
                        return true;
                      },
                      onEndIconPress: () {
                        isPinningLocation=false;
                        pickedLocation=null;
                        removeAddedMarker();
                        return true;
                      },
                      duration: Duration(milliseconds: 500),
                      color: Colors.white,
                      clockwise: false,
                    ),
                    //child: Icon(Icons.add),
                    backgroundColor: constants.LIGHT_GREEN,
                  )
              )
            ],
          )
              */
          /*
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.end,
            children: [
              Visibility(
                child:GestureDetector(
                    onTap: () =>showMenu(),
                  child: Container(
                      height: 30,
                      width: 140,
                      decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(15),
                        color:constants.LIGHT_GREEN,
                      ),
                      child: Center(
                          child:Text("Conferma",style: TextStyle(color: Colors.white,fontSize: 18),)
                      )
                  ),
                ),
                visible: (pickedLocation!=null),
              ),
              SizedBox(height: 20,),
              FloatingActionButton(
                onPressed: () {},
                child:AnimateIcons(
                  startIcon: Icons.add,
                  endIcon: Icons.close,
                  size:30,
                  controller: controllerAnimatedFloatingActionButton,
                  // add this tooltip for the start icon
                  startTooltip: 'Icons.add',
                  // add this tooltip for the end icon
                  endTooltip: 'Icons.close',
                  onStartIconPress: () {
                    isPinningLocation=true;
                    print("Clicked on Add Icon");
                    return true;
                  },
                  onEndIconPress: () {
                    isPinningLocation=false;
                    pickedLocation=null;
                    removeAddedMarker();
                    return true;
                  },
                  duration: Duration(milliseconds: 500),
                  color: Colors.white,
                  clockwise: false,
                ),
                //child: Icon(Icons.add),
                backgroundColor: constants.LIGHT_GREEN,
              )
            ],
          ),*/

    );
  }
}*/


