import 'package:auto_size_text/auto_size_text.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'dart:async';
import 'dart:ui';
import 'package:flutter/services.dart';
import 'package:we_clean_project/meetingMarker.dart';
import 'constants.dart' as constants;
import 'package:tcp_socket_connection/tcp_socket_connection.dart';
import 'dart:convert';
import 'package:we_clean_project/dateUtility.dart';
import 'package:hive/hive.dart';
import 'package:we_clean_project/hiveDBHelper.dart';

class MarkerInfo extends StatefulWidget {
  MarkerInfo({Key key, this.marker, this.controller}) : super(key: key);
  final MeetingMarker marker;
  final ScrollController controller;
  @override
  _MarkerInfo createState() => _MarkerInfo();
}

class _MarkerInfo extends State<MarkerInfo> {
  MeetingMarker marker;
  DateUtility dateUtility=new DateUtility();
  DateTime startDate;
  DateTime endDate;
  ScrollController controller;
  TcpSocketConnection server=new TcpSocketConnection("192.168.1.110", constants.SERVER_PORT);

  @override
  void initState() {
    marker=widget.marker;
    startDate=DateTime.parse(marker.startDateTime);
    endDate=DateTime.parse(marker.endDateTime);
    controller=widget.controller;
    if(controller==null){
      controller=new ScrollController();
    }
    //date=dateUtility.getMonthName(DateTime.parse(marker.startDateTime));
    super.initState();
  }

  String getDate(DateTime d){
    return d.day.toString()+" "+dateUtility.getMonthName(d)+" "+ d.year.toString();
  }

  String getHour(DateTime start, DateTime end){
    String startMinute;
    String endMinute;
    if(start.minute==0){
      startMinute="00";
    }else{
      startMinute=start.minute.toString();
    }
    if(end.minute==0){
      endMinute="00";
    }else{
      endMinute=end.minute.toString();
    }
    return start.hour.toString()+":"+startMinute+" - "+ end.hour.toString()+":"+endMinute;
    //return d.day.toString()+" "+dateUtility.getMonthName(d)+" "+ d.year.toString();
  }

  double getHeight(){
    var padding = MediaQuery.of(context).padding;
    double height = MediaQuery.of(context).size.height;
    double newheight = height - padding.top - padding.bottom-325;
    return newheight;
  }

  double getMinBottomHeight(){
    double height=getHeight();
    double newheight=height-503;
    if(newheight>=0)return newheight;
    return 10;
  }



  void askPartecipation() async{
    await server.connect(5000, "EOS", messageReceived);
    if(!HiveDBHelper.hasJoined(marker.id)) {
      server.sendMessage("JOIN%_%" + marker.id + "%_%EOS");
    }else{
      server.sendMessage("UNJOIN%_%" + marker.id + "%_%EOS");
    }
  }

  void messageReceived(String message){
    if(message.startsWith("OKJOIN")){

      setState(() {
        marker.actualPartecipants+=1;
      });
      if(!HiveDBHelper.hasJoined(marker.id)){
        HiveDBHelper.registerMeeting(marker.id);
        showDialog(
            context: context,
            builder: (context) {
              return StatefulBuilder(
                  builder: (context, setState) {
                    return Dialog(
                        backgroundColor: Colors.transparent,
                        child: Container(
                            width: 400,
                            height: 200,
                            decoration: BoxDecoration(
                              borderRadius: BorderRadius.circular(20),
                              color: constants.DARK_GREEN,
                              //color: Colors.blueGrey,
                            ),
                            child:Center(
                              child:Padding(
                                padding: EdgeInsets.all(20),

                                child: Text(
                                  "La tua partecipazione per l'incontro è stata confermata.\nRicordati di non mancare!\nSe per caso vuoi annullare la partecipazione puoi sempre farlo in questa pagina.",
                                  style: TextStyle(
                                    color: Colors.white,
                                    fontSize: 20,
                                  ),
                                ),
                              ),
                            )
                        )
                    );
                  }
              );
            }
        );
        print("REGISTRA");
      }else{
        HiveDBHelper.deleteMeeting(marker.id);
        print("ANNULLA");
      }
    }
    if(message.startsWith("OKUNJOIN")){
      setState(() {
        marker.actualPartecipants-=1;
      });
      if(!HiveDBHelper.hasJoined(marker.id)){
        HiveDBHelper.registerMeeting(marker.id);
        showDialog(
            context: context,
            builder: (context) {
              return StatefulBuilder(
                  builder: (context, setState) {
                    return Dialog(
                        backgroundColor: Colors.transparent,
                        child: Container(
                            width: 400,
                            height: 200,
                            decoration: BoxDecoration(
                              borderRadius: BorderRadius.circular(20),
                              color: constants.DARK_GREEN,
                              //color: Colors.blueGrey,
                            ),
                            child:Center(
                              child:Padding(
                                padding: EdgeInsets.all(20),

                                child: Text(
                                  "La tua partecipazione per l'incontro è stata confermata.\nRicordati di non mancare!\nSe per caso vuoi annullare la partecipazione puoi sempre farlo in questa pagina.",
                                  style: TextStyle(
                                    color: Colors.white,
                                    fontSize: 20,
                                  ),
                                ),
                              ),
                            )
                        )
                    );
                  }
              );
            }
        );
        print("REGISTRA");
      }else{
        HiveDBHelper.deleteMeeting(marker.id);
        print("ANNULLA");
      }
    }
    server.disconnect();
  }


  @override
  Widget build(BuildContext context) {


    return Container(
            constraints: BoxConstraints(
              minHeight: getHeight(), minWidth: double.infinity, ),
            decoration: BoxDecoration(
              borderRadius: BorderRadius.vertical(top: Radius.circular(30)),
              color: constants.WHITE,
              boxShadow: [
                BoxShadow(
                  color: Colors.black.withOpacity(0.3),
                  spreadRadius: 5,
                  blurRadius: 7,
                  offset: Offset(0, 3), // changes position of shadow
                ),
              ],
            ),
            child:Column(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
//mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              children: [
                Text(
                  "Titolo",
                  style: TextStyle(
                    fontSize: 20,
                    color: constants.GREY,
                    fontWeight: FontWeight.bold,
                  ),
                ),
                Padding(
                    padding: EdgeInsets.only(left: 20,right: 20),
                    child: Container(
                        width: double.infinity,
                        height: 50,
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(30),
                          color: constants.DARK_GREEN,
                          boxShadow: [
                            BoxShadow(
                              color: Colors.black.withOpacity(0.3),
                              spreadRadius: 2,
                              blurRadius: 7,
                              offset: Offset(0, 3), // changes position of shadow
                            ),
                          ],
                        ),
                        child:Padding(
                          padding: EdgeInsets.only(left:15,right: 15,top:12),
                          child: Text(

                            marker.title,
                            style: TextStyle(
                              fontSize: 20,
                              color: constants.WHITE,
                            ),
                          ),
                          /*child:TextField(
                              decoration: InputDecoration(
                                border: InputBorder.none,
                                hintText: "Pulizia presso...",
                                hintStyle: TextStyle(fontSize: 20.0),
                              ),
                              style: TextStyle(fontSize: 20,),
                              maxLines: 1,
                            )*/
                        )
                    )
                ),
                SizedBox(height: 5,),
                Text(
                  "Descrizione",
                  style: TextStyle(
                    fontSize: 20,
                    color: constants.GREY,
                    fontWeight: FontWeight.bold,
                  ),
                ),
                Padding(
                  padding: EdgeInsets.only(left:20,right: 20,),
                  child:ConstrainedBox(
                      constraints: new BoxConstraints(
                          minHeight: 200.0,
                          minWidth: double.infinity
                      ),
                      child: Container(
                          decoration: BoxDecoration(
                            borderRadius: BorderRadius.circular(30),
                            color: constants.DARK_GREEN,
                            boxShadow: [
                              BoxShadow(
                                color: Colors.black.withOpacity(0.3),
                                spreadRadius: 2,
                                blurRadius: 7,
                                offset: Offset(0, 3), // changes position of shadow
                              ),
                            ],
                          ),
                          child:Padding(
                            padding: EdgeInsets.only(left:15,right: 15,top:15,bottom: 15),
                            child: Text(
                              marker.description,
                              style: TextStyle(
                                fontSize: 20,
                                color: constants.WHITE,
                              ),
                            ),
                          )
                      )
                  ),
                ),
                SizedBox(height: 10,),
                Padding(
                    padding: EdgeInsets.only(left:30,right: 30,bottom: 10),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Text(
                          "N° partecipanti",
                          style: TextStyle(
                            fontSize: 20,
                            color: constants.GREY,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                        Container(
                            height: 50,
                            width: 120,
                            decoration: BoxDecoration(
                              borderRadius: BorderRadius.circular(30),
                              color: constants.DARK_GREEN,
                              boxShadow: [
                                BoxShadow(
                                  color: Colors.black.withOpacity(0.3),
                                  spreadRadius: 2,
                                  blurRadius: 7,
                                  offset: Offset(0, 3), // changes position of shadow
                                ),
                              ],
                            ),
                            child:Center(
                              child: Text(
                                marker.actualPartecipants.toString()+"/"+marker.maxPartecipants.toString(),
                                style: TextStyle(
                                  fontSize: 20,
                                  color: constants.WHITE,
                                ),
                              ),
                              /*child:TextField(
                                  textAlign: TextAlign.center,
                                  decoration: InputDecoration(
                                    border: InputBorder.none,
                                    hintText: 'Almeno 10',
                                    hintStyle: TextStyle(fontSize: 20.0,),
                                  ),
                                  keyboardType: TextInputType.number ,
                                  maxLines: 1,
                                  style: TextStyle(
                                    fontSize: 20,

                                  ),*/


                            )
                        )
                      ],
                    )
                ),
                SizedBox(height: 10,),
                Padding(
                    padding: EdgeInsets.only(left:30,right: 30,bottom: 10),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Text(
                          "Data",
                          style: TextStyle(
                            fontSize: 20,
                            color: constants.GREY,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                        Text(
                          getDate(startDate),
                          style: TextStyle(
                            fontSize: 16,
                            color: constants.GREY,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                        /*
                        Container(
                            height: 50,
                            width: 120,
                            decoration: BoxDecoration(
                              borderRadius: BorderRadius.circular(30),
                              color: constants.DARK_GREEN,
                              boxShadow: [
                                BoxShadow(
                                  color: Colors.black.withOpacity(0.3),
                                  spreadRadius: 2,
                                  blurRadius: 7,
                                  offset: Offset(0, 3), // changes position of shadow
                                ),
                              ],
                            ),
                            child:Center(
                              child: Text(
                                marker.startDateTime.toString()+"-"+marker.endDateTime.toString(),
                                style: TextStyle(
                                  fontSize: 20,

                                ),
                              ),
                            )
                        )*/
                      ],
                    )
                ),
                SizedBox(height: 10,),
                Padding(
                    padding: EdgeInsets.only(left:30,right: 30),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Text(
                          "Ora",
                          style: TextStyle(
                            fontSize: 20,
                            color: constants.GREY,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                        Text(
                          getHour(startDate,endDate),
                          style: TextStyle(
                            fontSize: 16,
                            color: constants.GREY,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                      ],
                    )
                ),
                GestureDetector(
                  onTap: ()=>askPartecipation(),
                  child: Container(
                    height: 50,
                    width: 200,
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(30),
                      color: constants.DARK_GREEN,
                      boxShadow: [
                        BoxShadow(
                          color: Colors.black.withOpacity(0.3),
                          spreadRadius: 2,
                          blurRadius: 7,
                          offset: Offset(0, 3), // changes position of shadow
                        ),
                      ],
                    ),
                    child:Center(
                      child:Text(
                        (!HiveDBHelper.hasJoined(marker.id))?"Partecipa":"Annulla",
                        style: TextStyle(
                          fontSize: 20,
                          color: constants.WHITE,
                          fontWeight: FontWeight.bold,
                        ),
                      ),
                    ),
                  ),
                ),
                SizedBox(height: 20,),/*
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    Container(
                      height: 65,
                      width: 65,
                      color: constants.WHITE,
                    ),

                    Container(
                      height: 65,
                      width: 65,
                      color: constants.WHITE,
                    ),
                  ],
                ),*/
                /*Container(
                  height: 50,
                  width: 200,
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(30),
                    color: constants.DARK_GREEN,
                    boxShadow: [
                      BoxShadow(
                        color: Colors.black.withOpacity(0.3),
                        spreadRadius: 2,
                        blurRadius: 7,
                        offset: Offset(0, 3), // changes position of shadow
                      ),
                    ],
                  ),
                  child:Center(
                    child:Text(
                      "Partecipa",
                      style: TextStyle(
                        fontSize: 20,
                        color: constants.WHITE,
                        fontWeight: FontWeight.bold,
                      ),
                    ),
                  ),
                ),*/

                //Expanded(child: Container()),

                /*
                Stack(
                  children: [
                    Container(
                      color: constants.WHITE,
                      height: 110,
                      alignment: Alignment.center,
                    ),

                    Column(
                      children: [
                        Container(
                          color: constants.WHITE,
//height: getHeight()-453,
                          constraints: BoxConstraints(
                              minHeight: getMinBottomHeight(), minWidth: double.infinity),
                          alignment: Alignment.center,
                          child: GestureDetector(
                            onTap: (){},
                            child:Container(
                              height: 50,
                              width: 200,
                              decoration: BoxDecoration(
                                borderRadius: BorderRadius.circular(30),
                                color: constants.DARK_GREEN,
                                boxShadow: [
                                  BoxShadow(
                                    color: Colors.black.withOpacity(0.3),
                                    spreadRadius: 2,
                                    blurRadius: 7,
                                    offset: Offset(0, 3), // changes position of shadow
                                  ),
                                ],
                              ),
                              child:Center(
                                child:Text(
                                  "Partecipa",
                                  style: TextStyle(
                                    fontSize: 20,
                                    color: constants.WHITE,
                                    fontWeight: FontWeight.bold,
                                  ),
                                ),
                              ),
                            ),
                          ),
                        ),
                      ],
                    ),
                  ],
                )*/
              ],
            )
          // ),
          //  ],
        );







/*
    return SingleChildScrollView(
      controller: controller,
      //physics: ClampingScrollPhysics(),
      //physics: const NeverScrollableScrollPhysics(),
     /* child:Column(
      children: [
      Container(
          height: 5000,
          width: 100,
          color: Colors.blue,
        ),*/
        child:Container(
            constraints: BoxConstraints(
                minHeight: getHeight(), minWidth: double.infinity, ),
            decoration: BoxDecoration(
              //borderRadius: BorderRadius.circular(30),
              borderRadius: BorderRadius.vertical(top: Radius.circular(25.0)),
              color: constants.WHITE,
              boxShadow: [
                BoxShadow(
                  color: Colors.black.withOpacity(0.3),
                  spreadRadius: 5,
                  blurRadius: 7,
                  offset: Offset(0, 3), // changes position of shadow
                ),
              ],
            ),
            child:Column(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
//mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              children: [
                Text(
                  "Titolo",
                  style: TextStyle(
                    fontSize: 20,
                    color: constants.GREY,
                    fontWeight: FontWeight.bold,
                  ),
                ),
                Padding(
                    padding: EdgeInsets.only(left: 20,right: 20),
                    child: Container(
                        width: double.infinity,
                        height: 50,
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(30),
                          color: constants.DARK_GREEN,
                          boxShadow: [
                            BoxShadow(
                              color: Colors.black.withOpacity(0.3),
                              spreadRadius: 2,
                              blurRadius: 7,
                              offset: Offset(0, 3), // changes position of shadow
                            ),
                          ],
                        ),
                        child:Padding(
                            padding: EdgeInsets.only(left:15,right: 15,top:12),
                          child: Text(

                            marker.title,
                            style: TextStyle(
                              fontSize: 20,
                              color: constants.WHITE,
                            ),
                          ),
                            /*child:TextField(
                              decoration: InputDecoration(
                                border: InputBorder.none,
                                hintText: "Pulizia presso...",
                                hintStyle: TextStyle(fontSize: 20.0),
                              ),
                              style: TextStyle(fontSize: 20,),
                              maxLines: 1,
                            )*/
                        )
                    )
                ),
                SizedBox(height: 5,),
                Text(
                  "Descrizione",
                  style: TextStyle(
                    fontSize: 20,
                    color: constants.GREY,
                    fontWeight: FontWeight.bold,
                  ),
                ),
                Padding(
                    padding: EdgeInsets.only(left:20,right: 20,),
                  child:ConstrainedBox(
                    constraints: new BoxConstraints(
                      minHeight: 200.0,
                      minWidth: double.infinity
    ),
                    child: Container(
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(30),
                          color: constants.DARK_GREEN,
                          boxShadow: [
                            BoxShadow(
                              color: Colors.black.withOpacity(0.3),
                              spreadRadius: 2,
                              blurRadius: 7,
                              offset: Offset(0, 3), // changes position of shadow
                            ),
                          ],
                        ),
                        child:Padding(
                            padding: EdgeInsets.only(left:15,right: 15,top:15,bottom: 15),
                          child: Text(
                            marker.description,
                            style: TextStyle(
                              fontSize: 20,
                              color: constants.WHITE,
                            ),
                          ),
                        )
                    )
                    ),
                ),
                SizedBox(height: 10,),
                Padding(
                    padding: EdgeInsets.only(left:30,right: 30,bottom: 10),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Text(
                          "N° partecipanti",
                          style: TextStyle(
                            fontSize: 20,
                            color: constants.GREY,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                        Container(
                            height: 50,
                            width: 120,
                            decoration: BoxDecoration(
                              borderRadius: BorderRadius.circular(30),
                              color: constants.DARK_GREEN,
                              boxShadow: [
                                BoxShadow(
                                  color: Colors.black.withOpacity(0.3),
                                  spreadRadius: 2,
                                  blurRadius: 7,
                                  offset: Offset(0, 3), // changes position of shadow
                                ),
                              ],
                            ),
                            child:Center(
                                child: Text(
                                  marker.actualPartecipants.toString()+"/"+marker.maxPartecipants.toString(),
                                  style: TextStyle(
                                    fontSize: 20,
                                    color: constants.WHITE,
                                  ),
                                ),
                                /*child:TextField(
                                  textAlign: TextAlign.center,
                                  decoration: InputDecoration(
                                    border: InputBorder.none,
                                    hintText: 'Almeno 10',
                                    hintStyle: TextStyle(fontSize: 20.0,),
                                  ),
                                  keyboardType: TextInputType.number ,
                                  maxLines: 1,
                                  style: TextStyle(
                                    fontSize: 20,

                                  ),*/


                            )
                        )
                      ],
                    )
                ),
                SizedBox(height: 10,),
                Padding(
                    padding: EdgeInsets.only(left:30,right: 30,bottom: 10),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Text(
                          "Data",
                          style: TextStyle(
                            fontSize: 20,
                            color: constants.GREY,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                        Text(
                         getDate(startDate),
                          style: TextStyle(
                            fontSize: 16,
                            color: constants.GREY,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                        /*
                        Container(
                            height: 50,
                            width: 120,
                            decoration: BoxDecoration(
                              borderRadius: BorderRadius.circular(30),
                              color: constants.DARK_GREEN,
                              boxShadow: [
                                BoxShadow(
                                  color: Colors.black.withOpacity(0.3),
                                  spreadRadius: 2,
                                  blurRadius: 7,
                                  offset: Offset(0, 3), // changes position of shadow
                                ),
                              ],
                            ),
                            child:Center(
                              child: Text(
                                marker.startDateTime.toString()+"-"+marker.endDateTime.toString(),
                                style: TextStyle(
                                  fontSize: 20,

                                ),
                              ),
                            )
                        )*/
                      ],
                    )
                ),
                SizedBox(height: 10,),
                Padding(
                    padding: EdgeInsets.only(left:30,right: 30),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Text(
                          "Ora",
                          style: TextStyle(
                            fontSize: 20,
                            color: constants.GREY,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                        Text(
                          getHour(startDate,endDate),
                          style: TextStyle(
                            fontSize: 16,
                            color: constants.GREY,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                      ],
                    )
                ),
                Row(
                  //mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    /*Container(
                      height: 65,
                      width: 65,
                      color: constants.WHITE,
                    ),*/
                    Container(
                      height: 50,
                      width: 200,
                      decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(30),
                        color: constants.DARK_GREEN,
                        boxShadow: [
                          BoxShadow(
                            color: Colors.black.withOpacity(0.3),
                            spreadRadius: 2,
                            blurRadius: 7,
                            offset: Offset(0, 3), // changes position of shadow
                          ),
                        ],
                      ),
                      child:Center(
                        child:Text(
                          "Partecipa",
                          style: TextStyle(
                            fontSize: 20,
                            color: constants.WHITE,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                      ),
                    ),
                    /*Container(
                      height: 65,
                      width: 65,
                      color: constants.WHITE,
                    ),*/
                  ],
                ),
                /*Container(
                  height: 50,
                  width: 200,
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(30),
                    color: constants.DARK_GREEN,
                    boxShadow: [
                      BoxShadow(
                        color: Colors.black.withOpacity(0.3),
                        spreadRadius: 2,
                        blurRadius: 7,
                        offset: Offset(0, 3), // changes position of shadow
                      ),
                    ],
                  ),
                  child:Center(
                    child:Text(
                      "Partecipa",
                      style: TextStyle(
                        fontSize: 20,
                        color: constants.WHITE,
                        fontWeight: FontWeight.bold,
                      ),
                    ),
                  ),
                ),*/

            //Expanded(child: Container()),

                /*
                Stack(
                  children: [
                    Container(
                      color: constants.WHITE,
                      height: 110,
                      alignment: Alignment.center,
                    ),

                    Column(
                      children: [
                        Container(
                          color: constants.WHITE,
//height: getHeight()-453,
                          constraints: BoxConstraints(
                              minHeight: getMinBottomHeight(), minWidth: double.infinity),
                          alignment: Alignment.center,
                          child: GestureDetector(
                            onTap: (){},
                            child:Container(
                              height: 50,
                              width: 200,
                              decoration: BoxDecoration(
                                borderRadius: BorderRadius.circular(30),
                                color: constants.DARK_GREEN,
                                boxShadow: [
                                  BoxShadow(
                                    color: Colors.black.withOpacity(0.3),
                                    spreadRadius: 2,
                                    blurRadius: 7,
                                    offset: Offset(0, 3), // changes position of shadow
                                  ),
                                ],
                              ),
                              child:Center(
                                child:Text(
                                  "Partecipa",
                                  style: TextStyle(
                                    fontSize: 20,
                                    color: constants.WHITE,
                                    fontWeight: FontWeight.bold,
                                  ),
                                ),
                              ),
                            ),
                          ),
                        ),
                      ],
                    ),
                  ],
                )*/
              ],
            )
       // ),
    //  ],
      ),
    );*/
  }
}